use `sonata_billing`;

create table `sessions` (
  `session_id` binary(20) not null,
  `data` text,
  `modified` timestamp not null default '0000-00-00 00:00:00' on update current_timestamp,
  primary key (`session_id`)
)engine=InnoDB character set utf8;

create table `modules` (
  `module_id` int(10) unsigned not null auto_increment,
  `module` varchar(255) not null,
  `label` varchar(255) not null,
  primary key (`module_id`),
  unique key `module` (`module`)
) engine=InnoDB default charset=utf8;

create table `module_controllers` (
  `controller_id` int(10) unsigned not null auto_increment,
  `module_id` int(10) unsigned not null,
  `controller` varchar(255) not null,
  `label` varchar(255) default null,
  primary key (`controller_id`),
  unique key `controller` (`controller`),
  key `module_id` (`module_id`),
  foreign key (`module_id`) references `modules` (`module_id`) on delete cascade
) engine=InnoDB default charset=utf8;

create table `controller_actions` (
  `action_id` int(10) unsigned not null auto_increment,
  `controller_id` int(10) unsigned not null,
  `action` varchar(255) not null,
  `label` varchar(255) default null,
  primary key (`action_id`),
  key `controller_id` (`controller_id`),
  foreign key (`controller_id`) references `module_controllers` (`controller_id`) on delete cascade
) engine=InnoDB default charset=utf8;

create table `roles` (
  `role_id` int(10) unsigned not null auto_increment,
  `name` varchar(255) not null,
  `default` enum('yes','no') not null default 'no',
  primary key (`role_id`)
) engine=InnoDB default charset=utf8;

create table `role_permissions` (
  `role_id` int(10) unsigned not null,
  `action_id` int(10) unsigned not null,
  key `action_id` (`action_id`),
  key `role_id` (`role_id`),
  foreign key (`action_id`) references `controller_actions` (`action_id`) on delete cascade,
  foreign key (`role_id`) references `roles` (`role_id`) on delete cascade
) engine=InnoDB default charset=utf8;

create table `system_permissions` (
  `system_permission_id` int(10) unsigned not null auto_increment,
  `description` varchar(255) not null,
  `extensions` longtext,
  `trunks` longtext,
  `cost_centers` longtext,
  primary key (`system_permission_id`)
) engine=InnoDB default charset=utf8;

create table `system_settings` (
  `setting` varchar(255) not null,
  `value` varchar(255) default null,
  primary key (`setting`),
  unique key `setting` (`setting`)
) engine=InnoDB default charset=utf8;

create table `countries` (
  `country_id` int(10) unsigned not null auto_increment,
  `country` varchar(255) not null,
  `iso` varchar(255) not null,
  primary key (`country_id`),
  unique key `country` (`country`,`iso`)
) engine=InnoDB default charset=utf8;

create table `users` (
  `user_id` int(10) unsigned not null auto_increment,
  `role_id` int(10) unsigned not null,
  `system_permission_id` int(10) unsigned default null,
  `user` varchar(255) not null,
  `password` binary(64) default null,
  `active_account` enum('yes','no') default 'yes',
  `created_at` timestamp not null default '0000-00-00 00:00:00' on update current_timestamp,
  primary key (`user_id`),
  unique key `user` (`user`),
  key `role_id` (`role_id`),
  key `system_permission_id` (`system_permission_id`),
  foreign key (`role_id`) references `roles` (`role_id`) on delete cascade,
  foreign key (`system_permission_id`) references `system_permissions` (`system_permission_id`)
) engine=InnoDB default charset=utf8;

create table `user_settings` (
  `user_id` int(10) unsigned not null,
  `setting` varchar(255) not null,
  `value` varchar(255) default null,
  key `user_id` (`user_id`),
  foreign key (`user_id`) references `users` (`user_id`) on delete cascade
) engine=InnoDB default charset=utf8;

create table `currencies` (
  `currency_id` int(10) unsigned not null auto_increment,
  `symbol` varchar(255) collate utf8_unicode_ci not null,
  `iso` varchar(255) collate utf8_unicode_ci not null,
  primary key (`currency_id`)
) engine=InnoDB default charset=utf8 collate=utf8_unicode_ci;

create table `currency_exchanges` (
  `exchange_id` int(10) unsigned not null auto_increment,
  `currency_id` int(10) unsigned not null,
  `date` timestamp not null default '0000-00-00 00:00:00',
  `rate` decimal(16,8) unsigned not null,
  primary key (`exchange_id`),
  key `currency_id` (`currency_id`),
  foreign key (`currency_id`) references `currencies` (`currency_id`)
) engine=InnoDB default charset=utf8;

create table `pbx_servers` (
  `pbx_server_id` int(10) unsigned not null auto_increment,
  `description` varchar(255) not null,
  `host` varchar(255) not null,
  `db_port` int(10) unsigned not null,
  `db_user` varchar(255) not null,
  `pbx_format` enum('ombutel','fpbx','issabel', 'vpbx') default null,
  `ssh_port` int(10) unsigned default null,
  `ssh_user` varchar(255) default null,
  `enabled` enum('yes','no') not null default 'no',
  primary key (`pbx_server_id`),
  unique key `host` (`host`)
) engine=InnoDB default charset=utf8;

create table `operators` (
  `operator_id` int(10) unsigned not null auto_increment,
  `name` varchar(255) not null,
  `default` enum('yes','no') default 'no',
  primary key (`operator_id`)
) engine=InnoDB default charset=utf8;

create table `prefix_categories` (
  `prefix_category_id` int(10) unsigned not null auto_increment,
  `name` varchar(255) not null,
  `description` varchar(255) default null,
  `pre_defined` enum('yes','no') default 'no',
  primary key (`prefix_category_id`),
  unique key `name` (`name`)
) engine=InnoDB default charset=utf8;

create table `carrier_rates` (
  `carrier_rate_id` int(10) unsigned not null auto_increment,
  `operator_id` int(10) unsigned not null,
  `prefix_category_id` int(10) unsigned default null,
  `description` varchar(255) not null,
  `strip` varchar(255) default null,
  `prepend` varchar(255) default null,
  `free_time` int(10) unsigned not null default '0',
  `connect_cost` decimal(16,8) not null default '0.00000000',
  `cost` decimal(16,8) not null default '0.00000000',
  `cost_interval` int(10) unsigned not null default '60',
  `call_direction` enum('in','out','loc','transit') not null default 'out',
  primary key (`carrier_rate_id`),
  key `operator_id` (`operator_id`),
  key `prefix_category_id` (`prefix_category_id`),
  foreign key (`operator_id`) references `operators` (`operator_id`) on delete cascade,
  foreign key (`prefix_category_id`) references `prefix_categories` (`prefix_category_id`) on delete set null
) engine=InnoDB default charset=utf8;

create table `carrier_prefixes` (
  `prefix` varchar(255) not null,
  `carrier_rate_id` int(10) unsigned not null,
  `description` varchar(255) default null,
  `strip` varchar(255) default null,
  `prepend` varchar(255) default null,
  `cost` decimal(16,8) default '0.00000000',
  `cost_interval` int(10) unsigned default '60',
  `sort` int(10) unsigned not null default '0',
  key `carrier_rate_id` (`carrier_rate_id`),
  foreign key (`carrier_rate_id`) references `carrier_rates` (`carrier_rate_id`) on delete cascade
) engine=InnoDB default charset=utf8;

create table `cdr` (
  `cdr_id` int(10) unsigned not null auto_increment,
  `pbx_server_id` int(10) unsigned not null,
  `datetime` timestamp not null default '0000-00-00 00:00:00',
  `source` varchar(255) default null,
  `destination` varchar(255) default null,
  `trunk` varchar(255) default null,
  `source_channel` varchar(255) default null,
  `destination_channel` varchar(255) default null,
  `direction` enum('out','in','loc','transit') not null default 'loc',
  `ringtime` int(10) unsigned not null,
  `duration` int(10) unsigned not null default '0',
  `uniqueid` varchar(255) not null,
  `disposition` enum('no_answer','congestion','failed','busy','answered') not null default 'no_answer',
  `accountcode` varchar(255) default null,
  `auth_code` varchar(255) default null,
  `customer_code` varchar(255) default null,
  `cost` decimal(16,4) unsigned not null,
  `undocumented` enum('yes','no') not null default 'no',
  `undocumented_code_reason` enum('0','2404','2405','2500') not null default '0',
  primary key (`cdr_id`),
  key `pbx_server_id` (`pbx_server_id`),
  foreign key (`pbx_server_id`) references `pbx_servers` (`pbx_server_id`) on delete cascade
) engine=InnoDB default charset=utf8;

create table `companies` (
  `company_id` int(10) unsigned not null auto_increment,
  `pbx_server_id` int(10) unsigned not null,
  `country_id` int(10) unsigned not null,
  `timezone` varchar(255) not null default 'utc',
  `company` varchar(255) not null,
  `address` varchar(255) default null,
  `telephone` varchar(255) default null,
  `email` varchar(255) default null,
  primary key (`company_id`),
  key `pbx_server_id` (`pbx_server_id`),
  key `country_id` (`country_id`),
  foreign key (`pbx_server_id`) references `pbx_servers` (`pbx_server_id`) on delete cascade,
  foreign key (`country_id`) references `countries` (`country_id`)
) engine=InnoDB default charset=utf8;

create table `company_settings` (
  `company_id` int(10) unsigned not null,
  `setting` varchar(255) not null,
  `value` varchar(255) default null,
  key `company_id` (`company_id`),
  foreign key (`company_id`) references `companies` (`company_id`)
) engine=InnoDB default charset=utf8;

create table `cost_centers` (
  `cc_id` int(10) unsigned not null auto_increment,
  `name` varchar(255) not null,
  `person_in_charge` varchar(255) not null,
  `default` enum('yes','no') default 'no',
  primary key (`cc_id`)
) engine=InnoDB default charset=utf8;

create table `customer_rates` (
  `customer_rate_id` int(10) unsigned not null auto_increment,
  `prefix_category_id` int(10) unsigned default null,
  `description` varchar(255) not null,
  `strip` varchar(255) default null,
  `prepend` varchar(255) default null,
  `free_time` int(10) unsigned not null default '0',
  `connect_cost` decimal(16,8) not null default '0.00000000',
  `cost` decimal(16,8) not null default '0.00000000',
  `cost_interval` int(10) unsigned not null default '60',
  `call_direction` enum('in','out','loc','transit') not null,
  primary key (`customer_rate_id`),
  key `prefix_category_id` (`prefix_category_id`),
  foreign key (`prefix_category_id`) references `prefix_categories` (`prefix_category_id`) on delete set null
) engine=InnoDB default charset=utf8;

create table `customer_prefixes` (
  `prefix` varchar(255) not null,
  `customer_rate_id` int(10) unsigned not null,
  `description` varchar(255) default null,
  `strip` varchar(255) default null,
  `prepend` varchar(255) default null,
  `cost` decimal(16,8) default null,
  `cost_interval` int(10) unsigned default null,
  `sort` int(10) unsigned default '0',
  key `customer_rate_id` (`customer_rate_id`),
  foreign key (`customer_rate_id`) references `customer_rates` (`customer_rate_id`) on delete cascade
) engine=InnoDB default charset=utf8;

create table `directory` (
  `directory_id` int(10) unsigned not null auto_increment,
  `full_name` varchar(255) not null,
  `phone` varchar(255) not null,
  `prefix` varchar(255) default null,
  primary key (`directory_id`),
  unique key `directory_phone_uindex` (`phone`)
) engine=InnoDB default charset=utf8;

create table `email_settings` (
  `type` enum('smtp','sendmail','php') not null,
  `smtp_secure` enum('tls','ssl') default null,
  `smtp_host` varchar(255) default null,
  `smtp_port` varchar(255) default null,
  `username` varchar(255) default null,
  `password` varchar(255) default null,
  `from_name` varchar(255) default null,
  `from_email` varchar(255) default null,
  `bcc_email` varchar(255) default null
) engine=InnoDB default charset=utf8;

create table `price_categories` (
  `price_category_id` int(10) unsigned not null auto_increment,
  `name` varchar(255) not null,
  `type` enum('carrier','customer') not null default 'carrier',
  `markup` decimal(16,8) unsigned not null default '0.00000000',
  `default` enum('yes','no') not null default 'no',
  primary key (`price_category_id`),
  unique key `name` (`name`)
) engine=InnoDB default charset=utf8;

create table `price_category_customer_rates_items` (
  `price_category_id` int(10) unsigned not null,
  `customer_rate_id` int(10) unsigned not null,
  `markup` decimal(16,8) unsigned default '0.00000000',
  key `price_category_id` (`price_category_id`),
  key `customer_rate_id` (`customer_rate_id`),
  foreign key (`price_category_id`) references `price_categories` (`price_category_id`) on delete cascade,
  foreign key (`customer_rate_id`) references `customer_rates` (`customer_rate_id`)
) engine=InnoDB default charset=utf8;

create table `extensions` (
  `extension_id` int(10) unsigned not null auto_increment,
  `cc_id` int(10) unsigned not null,
  `pbx_server_id` int(10) unsigned not null,
  `price_category_id` int(10) unsigned not null,
  `number` varchar(255) not null,
  `name` varchar(255) not null,
  primary key (`extension_id`),
  key `cc_id` (`cc_id`),
  key `pbx_server_id` (`pbx_server_id`),
  key `price_category_id` (`price_category_id`),
  foreign key (`cc_id`) references `cost_centers` (`cc_id`) on delete cascade,
  foreign key (`pbx_server_id`) references `pbx_servers` (`pbx_server_id`) on delete cascade,
  foreign key (`price_category_id`) references `price_categories` (`price_category_id`)
) engine=InnoDB default charset=utf8;

create table `menu` (
  `menu_id` int(10) unsigned not null auto_increment,
  `action_id` int(10) unsigned default null,
  `label` varchar(255) default null,
  `link` varchar(255) default null,
  `parent` int(10) unsigned not null default '0',
  `icon` varchar(255) not null,
  `has_sub` enum('yes','no') not null default 'no',
  `sort` int(11) default '0',
  primary key (`menu_id`),
  key `action_id` (`action_id`),
  foreign key (`action_id`) references `controller_actions` (`action_id`) on delete cascade
) engine=InnoDB default charset=utf8;

create table `rate_templates` (
  `rate_template_id` int(10) unsigned not null auto_increment,
  `country_id` int(10) unsigned not null,
  `description` varchar(255) not null,
  `author` varchar(255) not null,
  `filename` text not null,
  primary key (`rate_template_id`),
  key `country_id` (`country_id`),
  foreign key (`country_id`) references `countries` (`country_id`)
) engine=InnoDB default charset=utf8;

create table `report_filters` (
  `report_filter_id` int(10) unsigned not null auto_increment,
  `description` varchar(255) not null,
  `by` enum('schedule','prefixes') not null default 'schedule',
  primary key (`report_filter_id`)
) engine=InnoDB default charset=utf8;

create table `report_filter_by_prefix` (
  `report_filter_id` int(10) unsigned not null,
  `prefix` varchar(255) not null,
  `match_mode` enum('start_with','contains','end_with','exactly') default 'contains',
  `call_types` varchar(255) not null default 'out',
  `exclude` enum('yes','no') not null default 'no',
  key `report_filter_id` (`report_filter_id`),
  foreign key (`report_filter_id`) references `report_filters` (`report_filter_id`) on delete cascade
) engine=InnoDB default charset=utf8;

create table `report_filter_by_schedule` (
  `report_filter_id` int(10) unsigned not null,
  `day` enum('0','1','2','3','4','5','6') not null default '0',
  `hours` varchar(255) not null,
  key `report_filter_id` (`report_filter_id`),
  foreign key (`report_filter_id`) references `report_filters` (`report_filter_id`) on delete cascade
) engine=InnoDB default charset=utf8;

create table `report_templates` (
  `report_tpl_id` int(10) unsigned not null auto_increment,
  `user_id` int(10) unsigned not null,
  `company_id` int(10) unsigned not null,
  `description` varchar(255) not null,
  primary key (`report_tpl_id`),
  key `user_id` (`user_id`),
  key `company_id` (`company_id`),
  foreign key (`user_id`) references `users` (`user_id`) on delete cascade,
  foreign key (`company_id`) references `companies` (`company_id`) on delete cascade
) engine=InnoDB default charset=utf8;

create table `report_template_settings` (
  `report_tpl_id` int(10) unsigned not null,
  `param` varchar(255) not null,
  `value` varchar(255) default null,
  key `report_tpl_id` (`report_tpl_id`),
  foreign key (`report_tpl_id`) references `report_templates` (`report_tpl_id`) on delete cascade
) engine=InnoDB default charset=utf8;

create table `report_scheduler` (
  `rep_scheduler_id` int(10) unsigned not null auto_increment,
  `report_tpl_id` int(10) unsigned not null,
  `description` varchar(255) not null,
  `start_date` varchar(255) not null,
  `repeat` enum('one_time_event','daily','weekly','monthly','yearly') not null default 'one_time_event',
  `weekdays` varchar(255) default null,
  `frequency` int(10) unsigned default null,
  `next_run_date` varchar(255) not null,
  `emails` varchar(255) not null,
  `enabled` enum('yes','no') not null default 'yes',
  `force_execution` enum('yes','no') not null default 'no',
  primary key (`rep_scheduler_id`),
  key `report_tpl_id` (`report_tpl_id`),
  foreign key (`report_tpl_id`) references `report_templates` (`report_tpl_id`)
) engine=InnoDB default charset=utf8;

create table `trunks` (
  `trunk_id` int(10) unsigned not null auto_increment,
  `operator_id` int(10) unsigned not null,
  `pbx_server_id` int(10) unsigned not null,
  `tech` enum('sip','iax','pjsip','iax2','telephony') default null,
  `trunk` varchar(255) not null,
  `cid_num` varchar(255) default null,
  `description` varchar(255) default null,
  primary key (`trunk_id`),
  unique key `trunk` (`trunk`),
  key `operator_id` (`operator_id`),
  key `pbx_server_id` (`pbx_server_id`),
  foreign key (`operator_id`) references `operators` (`operator_id`) on delete cascade,
  foreign key (`pbx_server_id`) references `pbx_servers` (`pbx_server_id`) on delete cascade
) engine=InnoDB default charset=utf8;