var modal_element = null;

$(function(){
    configure_ajax();
    form_submit();
});

function configure_ajax(){
    $(document).ajaxStart(function() {
        $("#loader-container").show();
    }).ajaxStop(function() {
        $("#loader-container").hide();
    });
}

function form_submit(){
    $(document).on("submit", "form", function() {
        $(this).ajaxSubmit({
            type: "POST",
            success: process_server_response,
            url: window.location.pathname,
            resetForm: false,
            error: process_server_response
        });

        return false;
    });
}

function virtual_submit(data){
    $.ajax({
        type: "POST",
        url: window.location.pathname, //Only made request to the actual location
        data: data,
        success: function(Response){
            return process_server_response(Response);
        },
        error: process_server_error
    });
}

function server_request(action, data){
    $.ajax({
        type: "POST",
        url: window.location.pathname, //Only made request to the actual location
        data: {action: action, data: data},
        success: function(Response){
            return process_server_response(Response);
        },
        error: process_server_error
    });
}

function process_server_response(Response){
    close_open_modal();

    try{
        var data = JSON.parse($.base64.decode(Response));
    }catch(err){
	    swal({
		    title: 'Unexpected Server Response',
		    type: "error",
		    html: Response
	    });
    }

    if(typeof data == 'object'){
        switch (data.action){
            case 'notification':
                notification(data);
                break;
            case 'append':
                append_content(data);
                load_resources_files(data.resources);
                break;
            case 'replace':
                replace_content(data);
                load_resources_files(data.resources);
                notification(data.notification);
                break;
            case 'return':
                return data;
            case 'modal':
                show_modal(data);
                load_resources_files(data.resources);
                break;
            case 'reload':
                location.reload();
                break;
            case 'setup_value':
                setup_value(data);
                break;
            case 'confirmation':
                confirmation(data);
                break;
            case 'dependent_dropdown':
                dependent_dropdown(data);
                break;
            case 'validation_errors':
                validation_errors(data);
                break;
            case 'open_url':
                open_url(data);
                break;
            case 'module_menu':
                build_module_menu(data.menu);
                break;
            case 'app':
                loadAPP(data);
                break;
            case 'load_module':
                loadModule(data);
                break;
            default:
                console.log(data);
                break;
        }

        delegate();
    }
}

function append_content(data){
    hide_modal_backdrop();
    $(data.args.place).append(data.content);
}

function replace_content(data){
    hide_modal_backdrop();
    $(data.args.place).html(data.content);
}

function process_server_error(Response){
    console.log(Response.responseText);
}

function show_modal(data){
    var body = $("body");
    $("#" + data.dialog_id).remove();
    body.append(data.dialog);
    var dialog = modal_element = body.find("#" + data.dialog_id);
    dialog.modal('show');
}

function setup_value(data){
    var elem = $(document).find(data.element_id);
    elem.val(data.element_val);

    /*Special for licensing project*/
    var data_fg = elem.data('fg');
    $('.' + data_fg).removeClass('is-empty');
}

function close_open_modal(){
    if(modal_element !== null){
        modal_element.modal('hide');
        modal_element.remove();
        modal_element = null;
    }
}

function notification(data){
    if(typeof data.type === 'undefined'){
        return ;
    }

    toastr.options = {
        "closeButton": true,
        "newestOnTop": true,
        "positionClass": "toast-top-center"
    };

    switch(data.type){
        case 'info':
            toastr.info(data.message, data.title);
            break;

        case 'success':
            toastr.success(data.message, data.title);
            break;

        case 'warning':
            toastr.warning(data.message, data.title);
            break;

        case 'error':
            toastr.error(data.message, data.title);
            break;
    }
}

function confirmation(data){
    swal({
        title: data.title,
        text: data.msg,
        type: "warning",
        showCancelButton: true,
        confirmButtonColor: "#DD6B55",
        confirmButtonText: data.confirm_button,
        closeOnConfirm: true
    }).then(function (result) {
        if(result.value){
	        server_request(data.action_id,{'confirmed': true,'id': data.identifier});
        }
    });
}

function dependent_dropdown(data){
    var form = $(data.form);
    var child  = form.find(data.child);
    var parent = form.find(data.parent);
    var options = data.options;

    child.html('');

    $.each(options, function (index, item) {
        var option = '';
        option += '<option value="'+ item.value +'"';
        if(typeof item.params !== 'undefined') {
            $.each(item.params, function (param_index, param_val){
                option += ' '+ param_index +'="'+ param_val +'"';
            });
        }
        option += '> ' + item.content + '</option>';

        child.append(option);
    });

    child.trigger('change');
}

function validation_errors(data){
    swal({
        title: data.title,
        type: "warning",
        html: data.content
    });
}

function load_resources_files(resources){
    if(typeof resources.js !== 'undefined'){
        $.each(resources.js, function(index, item){
            var js_source = 'resources/modules/' + item;
            $('<script />', {type: 'text/javascript', 'src': js_source}).appendTo('head');
        });
    }

    if(typeof  resources.css !== 'undefined'){
        $.each(resources.css, function(index, item){
           var css_resource =  'resources/modules/' + item;
            $('<link />', {href: css_resource, rel: 'stylesheet', type: 'text/css'}).appendTo('head')
        });
    }
}

function hide_modal_backdrop(){
    var b = $("body");
    b.removeClass('modal-open');
    b.find('div.modal-backdrop').remove();
}

function open_url(data){
    var link = window.location.origin + '/' + data.url;
    var win = window.open(link, '_blank');
    if(win){
	    win.focus();
    }else{
        swal({
	        type: 'warning',
	        showCloseButton: false,
	        showCancelButton: false,
	        showConfirmButton: false,
            html: 'Please allow pop-ups for this domain to see reports faster. <br><br><br> ' +
            '<a href="'+ link +'" target="_blank" style="color: #3085D6;">Open Report</a>'
        });
    }
}

function build_module_menu(menu_items) {
    var container = document.getElementById('sidebar-container');
    var ul = document.createElement('ul');

    $.each(menu_items, function(index, item){
        var li = document.createElement('li');
        li.setAttribute('title',item.title);

        var link = document.createElement('a');
        link.setAttribute('onclick', 'javascript:server_request('+ item.index_action +',' + item.identifier + ')');
        var logo = document.createElement('img');
        logo.setAttribute('src', './resources/img/logo.png');
        var content = document.createElement('div');
        content.setAttribute('class','clear');
        var title = document.createElement('span');
        title.setAttribute('class','title');
        title.innerHTML = item.title;
        var description = document.createElement('span');
        description.setAttribute('class','description');
        description.innerHTML = item.sub_title;

        content.appendChild(title);
        content.appendChild(description);
        link.appendChild(logo);
        link.appendChild(content);
        li.appendChild(link);
        ul.appendChild(li);
    });

    container.innerHTML = '';
    container.appendChild(ul);

    $("input#module-menu-filter").fastLiveFilter('#sidebar-container > ul', {
        timeout: 200
    });
}

function loadAPP(data) {
    var b = $("body");
    b.html(data.content);
    b.promise().done(function () {
        if(data.launch_welcome){
	        server_request('init_modules');
        }
    });
}

function loadModule(data) {
    var place = $('#main-content');
    place.html(data.content);
    place.promise().done(function () {
        $("#content-header").html('<p>'+ data.header +'</p>');
	    hide_modal_backdrop();
	    load_resources_files(data.resources);
	    notification(data.notification);
    });
}
